@@ -30,7 +30,7 @@
 #define QT_FEATURE_webengine_system_lcms2 1
 #define QT_FEATURE_webengine_system_libdrm 1
 #define QT_FEATURE_webengine_system_libevent 1
-#define QT_FEATURE_webengine_system_libvpx -1
+#define QT_FEATURE_webengine_system_libvpx 1
 #define QT_FEATURE_webengine_system_libxml2 1
 #define QT_FEATURE_webengine_system_minizip 1
 #define QT_FEATURE_webengine_system_ninja 1
